<?php declare(strict_types=1);

namespace App\Entity;

use App\Repository\OrderItemRepository;
use Doctrine\ORM\Mapping as ORM;
use Symfony\Bridge\Doctrine\IdGenerator\UlidGenerator;
use Symfony\Bridge\Doctrine\Types\UlidType;
use Symfony\Component\Uid\Ulid;

#[ORM\Entity(repositoryClass: OrderItemRepository::class)]
class OrderItem
{
    #[ORM\Id]
    #[ORM\GeneratedValue(strategy: 'CUSTOM')]
    #[ORM\Column(type: UlidType::NAME, unique: true)]
    #[ORM\CustomIdGenerator(class: UlidGenerator::class)]
    private Ulid $id;

    #[ORM\ManyToOne(inversedBy: 'orderItems')]
    #[ORM\JoinColumn(nullable: false)]
    private FoodOrder|null $foodOrder = null;

    #[ORM\OneToOne(cascade: ['persist', 'remove'])]
    #[ORM\JoinColumn(nullable: false)]
    private MenuItem|null $menuItem = null;

    public function __construct()
    {
        $this->id = new Ulid;
    }

    public function getId(): Ulid
    {
        return $this->id;
    }

    public function getFoodOrder(): FoodOrder|null
    {
        return $this->foodOrder;
    }

    public function setFoodOrder(FoodOrder|null $foodOrder): static
    {
        $this->foodOrder = $foodOrder;
        return $this;
    }

    public function getMenuItem(): MenuItem|null
    {
        return $this->menuItem;
    }

    public function setMenuItem(MenuItem $menuItem): static
    {
        $this->menuItem = $menuItem;
        return $this;
    }
}
